@@ -75,7 +75,7 @@ namespace xt
      */
     template <class CT, class X>
     class xbroadcast : public xexpression<xbroadcast<CT, X>>,
-                       public xconst_iterable<xbroadcast<CT, X>>
+                       public xexpression_const_iterable<xbroadcast<CT, X>>
     {
 
     public:
@@ -91,7 +91,7 @@ namespace xt
         using size_type = typename xexpression_type::size_type;
         using difference_type = typename xexpression_type::difference_type;
         
-        using iterable_base = xconst_iterable<self_type>;
+        using iterable_base = xexpression_const_iterable<self_type>;
         using shape_type = typename iterable_base::shape_type;
 
         using stepper = typename iterable_base::stepper;
