@@ -18,19 +18,9 @@ namespace xt
 {
 
     /***********************
-     * broadcast functions *
+     * iterator meta utils *
      ***********************/
 
-    template <class S1, class S2>
-    bool broadcast_shape(const S1& input, S2& output);
-
-    template <class S1, class S2>
-    bool broadcastable(const S1& s1, S2& s2);
-
-    /************
-     * xstepper *
-     ************/
-
     namespace detail
     {
         template <class C>
@@ -67,6 +57,10 @@ namespace xt
     template <class C>
     using xindex_type_t = typename detail::index_type_impl<C>::type;
  
+    /************
+     * xstepper *
+     ************/
+
     template <class C>
     class xstepper
     {
@@ -116,6 +110,60 @@ namespace xt
                            IT& index,
                            const ST& shape);
 
+    /********************
+     * xindexed_stepper *
+     ********************/
+
+    template <class E, bool is_const = true>
+    class xindexed_stepper
+    {
+
+    public:
+
+        using self_type = xindexed_stepper<E, is_const>;
+        using xexpression_type = std::conditional_t<is_const, const E, E>;
+
+        using value_type = typename xexpression_type::value_type;
+        using reference = std::conditional_t<is_const,
+                                             typename xexpression_type::const_reference,
+                                             typename xexpression_type::reference>;
+        using pointer = std::conditional_t<is_const,
+                                           typename xexpression_type::const_pointer,
+                                           typename xexpression_type::pointer>;
+        using size_type = typename xexpression_type::size_type;
+        using difference_type = typename xexpression_type::difference_type;
+
+        using shape_type = typename xexpression_type::shape_type;
+        using index_type = xindex_type_t<shape_type>;
+
+        xindexed_stepper() = default;
+        xindexed_stepper(xexpression_type* e, size_type offset, bool end = false) noexcept;
+
+        reference operator*() const;
+
+        void step(size_type dim, size_type n = 1);
+        void step_back(size_type dim, size_type n = 1);
+        void reset(size_type dim);
+
+        void to_end();
+
+        bool equal(const self_type& rhs) const;
+
+    private:
+
+        xexpression_type* p_e;
+        index_type m_index;
+        size_type m_offset;
+    };
+
+    template <class C, bool is_const>
+    bool operator==(const xindexed_stepper<C, is_const>& lhs,
+                    const xindexed_stepper<C, is_const>& rhs);
+
+    template <class C, bool is_const>
+    bool operator!=(const xindexed_stepper<C, is_const>& lhs,
+                    const xindexed_stepper<C, is_const>& rhs);
+
     /*************
      * xiterator *
      *************/
@@ -204,46 +252,6 @@ namespace xt
     bool operator!=(const xiterator<It, S>& lhs,
                     const xiterator<It, S>& rhs);
 
-    /**************************************
-     * broadcast functions implementation *
-     **************************************/
-
-    template <class S1, class S2>
-    inline bool broadcast_shape(const S1& input, S2& output)
-    {
-        bool trivial_broadcast = (input.size() == output.size());
-        auto input_iter = input.crbegin();
-        auto output_iter = output.rbegin();
-        for(;input_iter != input.crend(); ++input_iter, ++output_iter)
-        {
-            if(*output_iter == 1)
-            {
-                *output_iter = *input_iter;
-            }
-            else if((*input_iter != 1) && (*output_iter != *input_iter))
-            {
-                throw broadcast_error(output, input);
-            }
-            trivial_broadcast = trivial_broadcast && (*output_iter == *input_iter);
-        }
-        return trivial_broadcast;
-    }
-
-    template <class S1, class S2>
-    inline bool broadcastable(const S1& s1, const S2& s2)
-    {
-        auto iter1 = s1.crbegin();
-        auto iter2 = s2.crbegin();
-        for(;iter1 != s1.crend() && iter2 != s2.crend(); ++iter1, ++iter2)
-        {
-            if((*iter2 != 1) && (*iter1 != 1) && (*iter2 != *iter1))
-            {
-                return false;
-            }
-        }
-        return true;
-    }
-
     /***************************
      * xstepper implementation *
      ***************************/
@@ -334,6 +342,71 @@ namespace xt
         }
     }
 
+    /***********************************
+     * xindexed_stepper implementation *
+     ***********************************/
+    
+    template <class C, bool is_const>
+    inline xindexed_stepper<C, is_const>::xindexed_stepper(xexpression_type* e, size_type offset, bool end) noexcept
+        : p_e(e), m_index(make_sequence<index_type>(e->shape().size(), size_type(0))), m_offset(offset)
+    {
+        if (end)
+            to_end();
+    }
+
+    template <class C, bool is_const>
+    inline auto xindexed_stepper<C, is_const>::operator*() const -> reference
+    {
+        return p_e->element(m_index.cbegin(), m_index.cend());
+    }
+
+    template <class C, bool is_const>
+    inline void xindexed_stepper<C, is_const>::step(size_type dim, size_type n)
+    {
+        if (dim >= m_offset)
+            m_index[dim - m_offset] += n;
+    }
+
+    template <class C, bool is_const>
+    inline void xindexed_stepper<C, is_const>::step_back(size_type dim, size_type n)
+    {
+        if (dim >= m_offset)
+            m_index[dim - m_offset] -= n;
+    }
+
+    template <class C, bool is_const>
+    inline void xindexed_stepper<C, is_const>::reset(size_type dim)
+    {
+        if (dim >= m_offset)
+            m_index[dim - m_offset] = 0;
+    }
+
+    template <class C, bool is_const>
+    inline void xindexed_stepper<C, is_const>::to_end()
+    {
+        m_index = p_e->shape();
+    }
+
+    template <class C, bool is_const>
+    inline bool xindexed_stepper<C, is_const>::equal(const self_type& rhs) const
+    {
+        return p_e == rhs.p_e && m_index == rhs.m_index && m_offset == rhs.m_offset;
+    }
+
+    template <class C, bool is_const>
+    inline bool operator==(const xindexed_stepper<C, is_const>& lhs,
+                           const xindexed_stepper<C, is_const>& rhs)
+    {
+        return lhs.equal(rhs);
+    }
+
+    template <class C, bool is_const>
+    inline bool operator!=(const xindexed_stepper<C, is_const>& lhs,
+                           const xindexed_stepper<C, is_const>& rhs)
+    {
+        return !lhs.equal(rhs);
+    }
+
     /****************************
      * xiterator implementation *
      ****************************/
@@ -421,4 +494,3 @@ namespace xt
 }
 
 #endif
-
