@@ -58,7 +58,7 @@ namespace xt
         }
 
         template <template <class...> class F, class... E>
-        struct build_xfunction_type
+        struct xfunction_type
         {
             using type = xfunction<F<common_value_type_t<std::decay_t<E>...>>,
                                    typename F<common_value_type_t<std::decay_t<E>...>>::result_type,
@@ -66,12 +66,12 @@ namespace xt
         };
 
         // On MSVC, the second argument of enable_if_t is always evaluated, even if the condition is false.
-        // Wrapping the xfunction type in the build_xfunction_type metafunction avoids this evaluation when
+        // Wrapping the xfunction type in the xfunction_type metafunction avoids this evaluation when
         // the condition is false, since it leads to a tricky bug preventing from using operator+ and operator-
         // on vector and arrays iterators.
         template <template <class...> class F, class... E>
-        using get_xfunction_type_t = typename std::enable_if_t<has_xexpression<std::decay_t<E>...>::value,
-                                                               build_xfunction_type<F, E...>>::type;
+        using xfunction_type_t = typename std::enable_if_t<has_xexpression<std::decay_t<E>...>::value,
+                                                           xfunction_type<F, E...>>::type;
     }
 
     /*************
@@ -93,7 +93,7 @@ namespace xt
      */
     template <class E>
     inline auto operator+(E&& e) noexcept
-        -> detail::get_xfunction_type_t<detail::identity, E>
+        -> detail::xfunction_type_t<detail::identity, E>
     {
         return detail::make_xfunction<detail::identity>(std::forward<E>(e));
     }
@@ -109,7 +109,7 @@ namespace xt
     */
     template <class E>
     inline auto operator-(E&& e) noexcept
-        -> detail::get_xfunction_type_t<std::negate, E>
+        -> detail::xfunction_type_t<std::negate, E>
     {
         return detail::make_xfunction<std::negate>(std::forward<E>(e));
     }
@@ -126,7 +126,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto operator+(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::plus, E1, E2>
+        -> detail::xfunction_type_t<std::plus, E1, E2>
     {
         return detail::make_xfunction<std::plus>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -143,7 +143,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto operator-(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::minus, E1, E2>
+        -> detail::xfunction_type_t<std::minus, E1, E2>
     {
         return detail::make_xfunction<std::minus>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -160,7 +160,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto operator*(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::multiplies, E1, E2>
+        -> detail::xfunction_type_t<std::multiplies, E1, E2>
     {
         return detail::make_xfunction<std::multiplies>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -177,7 +177,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto operator/(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::divides, E1, E2>
+        -> detail::xfunction_type_t<std::divides, E1, E2>
     {
         return detail::make_xfunction<std::divides>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -198,7 +198,7 @@ namespace xt
      */
     template <class E1, class E2>
     inline auto operator||(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::logical_or, E1, E2>
+        -> detail::xfunction_type_t<std::logical_or, E1, E2>
     {
         return detail::make_xfunction<std::logical_or>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -215,7 +215,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto operator&&(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::logical_and, E1, E2>
+        -> detail::xfunction_type_t<std::logical_and, E1, E2>
     {
         return detail::make_xfunction<std::logical_and>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -231,7 +231,7 @@ namespace xt
     */
     template <class E>
     inline auto operator!(E&& e) noexcept
-        -> detail::get_xfunction_type_t<std::logical_not, E>
+        -> detail::xfunction_type_t<std::logical_not, E>
     {
         return detail::make_xfunction<std::logical_not>(std::forward<E>(e));
     }
@@ -252,7 +252,7 @@ namespace xt
      */
     template <class E1, class E2>
     inline auto operator<(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::less, E1, E2>
+        -> detail::xfunction_type_t<std::less, E1, E2>
     {
         return detail::make_xfunction<std::less>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -269,7 +269,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto operator<=(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::less_equal, E1, E2>
+        -> detail::xfunction_type_t<std::less_equal, E1, E2>
     {
         return detail::make_xfunction<std::less_equal>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -286,7 +286,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto operator>(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::greater, E1, E2>
+        -> detail::xfunction_type_t<std::greater, E1, E2>
     {
         return detail::make_xfunction<std::greater>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -303,7 +303,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto operator>=(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::greater_equal, E1, E2>
+        -> detail::xfunction_type_t<std::greater_equal, E1, E2>
     {
         return detail::make_xfunction<std::greater_equal>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -364,7 +364,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto equal(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::equal_to, E1, E2>
+        -> detail::xfunction_type_t<std::equal_to, E1, E2>
     {
         return detail::make_xfunction<std::equal_to>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -381,7 +381,7 @@ namespace xt
     */
     template <class E1, class E2>
     inline auto not_equal(E1&& e1, E2&& e2) noexcept
-        -> detail::get_xfunction_type_t<std::not_equal_to, E1, E2>
+        -> detail::xfunction_type_t<std::not_equal_to, E1, E2>
     {
         return detail::make_xfunction<std::not_equal_to>(std::forward<E1>(e1), std::forward<E2>(e2));
     }
@@ -400,7 +400,7 @@ namespace xt
     */
     template <class E1, class E2, class E3>
     inline auto where(E1&& e1, E2&& e2, E3&& e3) noexcept
-        -> detail::get_xfunction_type_t<detail::conditional_ternary, E1, E2, E3>
+        -> detail::xfunction_type_t<detail::conditional_ternary, E1, E2, E3>
     {
          return detail::make_xfunction<detail::conditional_ternary>(std::forward<E1>(e1), std::forward<E2>(e2), std::forward<E3>(e3));
     }
@@ -423,7 +423,8 @@ namespace xt
         index_type idx(arr.dimension(), 0);
         std::vector<index_type> indices;
 
-        auto next_idx = [&shape](index_type& idx) {
+        auto next_idx = [&shape](index_type& idx)
+        {
             for (int i = int(shape.size() - 1); i >= 0; --i)
             {
                 if (idx[i] >= shape[i] - 1)
@@ -440,7 +441,7 @@ namespace xt
             return index_type();
         };
 
-        size_type total_size = std::accumulate(shape.begin(), shape.end(), size_type(1), std::multiplies<>());
+        size_type total_size = compute_size(shape);
         for (size_type i = 0; i < total_size; i++, next_idx(idx))
         {
             if (arr[idx])
